pub enum MutVars {
I8(String, i8),
I16(String, i16),
I32(String, i32),
I64(String, i64),
F32(String, f32),
F64(String, f64),
Char(String, char),
String(String, String),
}Variants
I8(String, i8)
Represents a mutable 8-bit signed integer variable.
The first argument is the name of the variable, and the second argument is the value of the variable.
I16(String, i16)
Represents a mutable 16-bit signed integer variable.
The first argument is the name of the variable, and the second argument is the value of the variable.
I32(String, i32)
Represents a mutable 32-bit signed integer variable.
The first argument is the name of the variable, and the second argument is the value of the variable.
I64(String, i64)
Represents a mutable 64-bit signed integer variable.
The first argument is the name of the variable, and the second argument is the value of the variable.
F32(String, f32)
Represents a mutable 32-bit floating-point number variable.
The first argument is the name of the variable, and the second argument is the value of the variable.
F64(String, f64)
Represents a mutable 64-bit floating-point number variable.
The first argument is the name of the variable, and the second argument is the value of the variable.
Char(String, char)
Represents a mutable character variable.
The first argument is the name of the variable, and the second argument is the value of the variable.
String(String, String)
Represents a mutable string variable.
The first argument is the name of the variable, and the second argument is the value of the variable.